==> vdr-addon-noad_0.3.2b.orig.tar.gz: vdr-addon-noad-0.3.2b.orig/noad.h <==
#ifndef __NOAD_H__
#define __NOAD_H__

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <getopt.h>
#ifdef HAVE_SYS_TIME_H
#include <sys/time.h>
#include <signal.h>
#endif
#include <inttypes.h>


#include "vdr_cl.h"
#include "noaddata.h"
#include "ccontrol.h"

#define DEMUX_PAYLOAD_START 1

#define FRAMESPERSEC 25
#define FRAMESPERMIN 1500
#define BIGSTEP (15 * FRAMESPERSEC)
#define SMALLSTEP 1
#define LOGOSTABLETIME 40*FRAMESPERSEC

extern noadData *data;
extern CControl* cctrl;

//statistic data
extern int totalFrames;
extern int totalDecodedFrames;
extern int decodedFramesForLogoDetection;
extern int decodedFramesForLogoCheck;
extern int secsForLogoDetection;
extern int secsForLogoCheck;
extern int secsForScan;

bool detectBlacklines(int _index, int iFramesToCheck, cFileName *cfn, int& iTopLines, int& iBottomLines);
bool detectBlacklines(cMarks *marks, cFileName *cfn, int& iTopLines, int& iBottomLines);
void setCB_Func( cbfunc f );
cbfunc getCB_Func(void);
void decode_mpeg2 (uint8_t * current, uint8_t * end);
int demux (uint8_t * buf, uint8_t * end, int flags);
bool StdCallBack(void *buffer, int width, int height, void *yufbuf );
int drawCallback( void *buffer, int width, int height, void *yufbuf );
int BlacklineCallback( void *buffer, int width, int height, void *yufbuf );
int BlackframeCallback( void *buffer, int width, int height, void *yufbuf );
int checkCallback( void *buffer, int width, int height, void *yufbuf );
bool checkLogo(cFileName *cfn, int startpos);
bool doLogoDetection(cFileName *cfn, int curIndex);
void reInitNoad(int top, int bottom );
bool detectLogo( cFileName *cfn, char* logoname );
int checkLogoState(cFileName *cfn, int iState, int iCurrentFrame, int FramesToSkip, int FramesToCheck);
int findLogoChange(cFileName *cfn, int iState, int& iCurrentFrame,
                   int FramesToSkip, int repeatCheckframes=0);
void MarkToggle(cMarks *marks, int index);
void moveMark( cMarks *marks, cMark *m, int iNewPos);
void listMarks(cMarks *marks);
#define MINBLACKLINES 15
#define MAXBLACKLINEDIFF 10
#define BACKFRAMES (FRAMESPERSEC*90)
void checkOnMarkBlacklines( cMarks *marks, cMark *m, cFileName *cfn);
bool checkOnMark( cMarks *marks, cMark *m, cFileName *cfn, bool bForward, int iCheckTime);
int displayIFrame(int iFrameIndex);
bool checkBlacklineOnMark( cMarks *marks, cMark *m, cFileName *cfn, bool bForward, int iCheckTime, int iTopLines, int iBottomLines);
bool checkBlackFrameOnMark( cMarks *marks, cMark *m, cFileName *cfn, bool bForward, int iCheckTime );
void checkOnMarks(cMarks *marks, cFileName *cfn);
bool checkBlackFramesOnMarks(cMarks *marks, cFileName *cfn);
bool detectBlacklines(cMarks *marks, cFileName *cfn, int& iTopLines, int& iBottomLines);
bool detectBlacklines(cMarks *marks, cFileName *cfn, int& iTopLines, int& iBottomLines);
bool detectBlacklines(int _index, int iFramesToCheck, cFileName *cfn, int& iTopLines, int& iBottomLines);
bool checkBlacklineOnMarks(cMarks *marks, cFileName *cfn);
void MarkCleanup(cMarks *marks, cFileName *cfn);
const char *getVersion();

int doX11Scan(noadData *thedata, const char *fName, int iNumFrames );
const char *myTime(time_t tim);
void clearStats();
#endif

==> vdr-addon-noad_0.4.2.orig.tar.gz: vdr-addon-noad-0.4.2.orig/noad.h <==
#ifndef __NOAD_H__
#define __NOAD_H__

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <getopt.h>
#ifdef HAVE_SYS_TIME_H
#include <sys/time.h>
#include <signal.h>
#endif
#include <inttypes.h>


#include "vdr_cl.h"
#include "noaddata.h"
#include "ccontrol.h"

// in vdr_cl.h #define FRAMESPERSEC 25
// in vdr_cl.h #define FRAMESPERMIN (FRAMESPERSEC*60)
#define BIGSTEP (15 * FRAMESPERSEC)
#define SMALLSTEP 1
#define LOGOSTABLETIME 40*FRAMESPERSEC

#define FRAMES_FOR_AC51DETECT (FRAMESPERSEC*1000)
#define AC3_51DETECT_SKIP 250

extern noadData *data;
extern CControl* cctrl;

//statistic data
extern int totalFrames;
extern int totalDecodedFrames;
extern int decodedFramesForLogoDetection;
extern int decodedFramesForLogoCheck;
extern int decodedFramesForAC3Detection;
extern int decodedFramesForAC3Check;
extern int secsForLogoDetection;
extern int secsForLogoCheck;
extern int secsForAC3Detection;
extern int secsForAC3Scan;
extern int secsForScan;
extern bool hasBlackLines;
extern bool hasAC3;
extern bool hasOverlaps;
extern int picWidth;
extern int picHeight;
extern int osdMsg;
extern bool markComments;
// control-data
extern bool saveLogo;
extern bool backupMarks;
extern bool doPass2;
extern bool useSceneChangeDetection;
extern bool detectOverlaps;
extern bool useAudioDetection;
extern bool logoJumpDetection;
extern bool isNelonen;

bool detectBlacklines(int _index, int iFramesToCheck, cFileName *cfn, int& iTopLines, int& iBottomLines);
bool detectBlacklines(cMarks *marks, cFileName *cfn, int& iTopLines, int& iBottomLines);
void setCB_Func( cbfunc f );
cbfunc getCB_Func(void);

bool StdCallBack(void *buffer, int width, int height, void *yufbuf );
int simpleCallback( void *buffer, int width, int height, void *yufbuf );
int drawCallback( void *buffer, int width, int height, void *yufbuf );
int BlacklineCallback( void *buffer, int width, int height, void *yufbuf );
int BlackframeCallback( void *buffer, int width, int height, void *yufbuf );
int checkCallback( void *buffer, int width, int height, void *yufbuf );

bool checkLogo(cFileName *cfn, int startpos);
bool checkLogoShort(cFileName *cfn, int startpos);
bool doLogoDetection(cFileName *cfn, int curIndex);

void reInitNoad(int top, int bottom );
bool detectLogo( cFileName *cfn, char* logoname, int iStartFrame = 0 );
int checkLogoState(cFileName *cfn, int iState, int iCurrentFrame, int FramesToSkip, int FramesToCheck);
int findLogoChange(cFileName *cfn, int iState, int& iCurrentFrame,
                   int FramesToSkip, int repeatCheckframes=0);
void MarkToggle(cMarks *marks, int index, const char *Comment=NULL);
void moveMark( cMarks *marks, cMark *m, int iNewPos, const char *Comment=NULL);
void listMarks(cMarks *marks);
#define MINBLACKLINES 15
#define MAXBLACKLINEDIFF 10
#define BACKFRAMES (FRAMESPERSEC*90)
#define OFFBACKFRAMES (FRAMESPERSEC*30)
void checkOnMarkBlacklines( cMarks *marks, cMark *m, cFileName *cfn);
void checkOffMarkBlacklines( cMarks *marks, cMark *m, cFileName *cfn);
bool checkOnMark( cMarks *marks, cMark *m, cFileName *cfn, bool bForward, int iCheckTime);
int displayIFrame(int iFrameIndex);
bool checkBlacklineOnMark( cMarks *marks, cMark *m, cFileName *cfn, bool bForward, int iCheckTime, int iTopLines, int iBottomLines);
bool checkBlackFrameOnMark( cMarks *marks, cMark *m, cFileName *cfn, bool bForward, int iCheckTime );
void checkOnMarks(cMarks *marks, cFileName *cfn);
bool checkBlackFramesOnMarks(cMarks *marks, cFileName *cfn);
bool detectBlacklines(cMarks *marks, cFileName *cfn, int& iTopLines, int& iBottomLines);
bool detectBlacklines(cMarks *marks, cFileName *cfn, int& iTopLines, int& iBottomLines);
bool detectBlacklines(int _index, int iFramesToCheck, cFileName *cfn, int& iTopLines, int& iBottomLines);
bool checkBlacklineOnMarks(cMarks *marks, cFileName *cfn);
void MarkCleanup(cMarks *marks, cFileName *cfn);
void pass2a(cMarks *marks, cFileName *cfn);
const char *getVersion();

int doX11Scan(noadData *thedata, const char *fName, int iNumFrames );
const char *myTime(time_t tim);
void clearStats();

int checkScenecheckOnMark( cMarks *marks, cMark *m );
void checkMarksOnIFrames(noadData *thedata, const char *fName);

#ifdef VNOAD
int scanRecord( int iNumFrames, cMarks *marks = NULL );
#endif

#endif
